@@ -1,13 +1,30 @@
 use strict;
 use warnings;
-package Email::Simple::FromHandle;
-{
-  $Email::Simple::FromHandle::VERSION = '0.054';
-}
+package Email::Simple::FromHandle 0.055;
 use Email::Simple 2.004;
 use parent 'Email::Simple';
 # ABSTRACT: an Email::Simple but from a handle
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   use Email::Simple::FileHandle;
+#pod
+#pod   open my $fh, "<", "email.msg";
+#pod
+#pod   my $email = Email::Simple::FromHandle->new($fh);
+#pod
+#pod   print $email->as_string;
+#pod   # or
+#pod   $email->stream_to(\*STDOUT);
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This is a subclass of Email::Simple which can accept filehandles as the source
+#pod of an email.  It will keep a reference to the filehandle and read from it when
+#pod it needs to access the body.  It does not load the entire body into memory and
+#pod keep it there.
+#pod
+#pod =cut
 
 use Carp ();
 use IO::String;
@@ -15,12 +32,37 @@ use Fcntl qw(SEEK_SET);
 
 my $crlf = qr/\x0a\x0d|\x0d\x0a|\x0a|\x0d/; # We are liberal in what we accept.
 
+#pod =head1 METHODS
+#pod
+#pod In addition to the standard L<Email::Simple> interface, the following methods
+#pod are provided:
+#pod
+#pod =head2 handle
+#pod
+#pod This returns the handle given to construct the message.  If the message was
+#pod constructed with a string instead, it returns an IO::String object.
+#pod
+#pod =cut
 
 sub handle { $_[0]->{handle} }
 
+#pod =head2 body_pos
+#pod
+#pod This method returns the position in the handle at which the body begins.  This
+#pod is used for seeking when re-reading the body.
+#pod
+#pod =cut
 
 sub body_pos { $_[0]->{body_pos} }
 
+#pod =head2 reset_handle
+#pod
+#pod This method seeks the handle to the body position and resets the header-line
+#pod iterator.
+#pod
+#pod For unseekable handles (pipes, sockets), this will die.
+#pod
+#pod =cut
 
 sub _is_seekable {
   my ($self) = @_;
@@ -47,6 +89,15 @@ sub reset_handle {
     or Carp::croak "can't seek: $!";
 }
 
+#pod =head2 getline
+#pod
+#pod   $str = $email->getline;
+#pod
+#pod This method returns either the next line from the headers or the next line from
+#pod the underlying filehandle.  It only returns a single line, regardless of
+#pod context.  Returns C<undef> on EOF.
+#pod
+#pod =cut
 
 sub getline {
   my ($self) = @_;
@@ -60,6 +111,34 @@ sub getline {
   return shift @{$self->{_get_head_lines}} || <$handle>;
 }
 
+#pod =head2 stream_to
+#pod
+#pod   $email->stream_to($fh, [ \%arg ]);
+#pod
+#pod This method efficiently writes the message to the passed-in filehandle.  
+#pod
+#pod The second argument may be a hashref of options:
+#pod
+#pod =over 4
+#pod
+#pod =item B<reset_handle:>
+#pod
+#pod Whether or not to call C<< $self->reset_handle >> before reading the message
+#pod (default true). 
+#pod
+#pod =item B<chunk_size:>
+#pod
+#pod Number of bytes to read from C<< $self->handle >> at once (default 65536).
+#pod
+#pod =item B<write:>
+#pod
+#pod Coderef to use to print instead of C<print $fh $chunk>.  This coderef will
+#pod receive two arguments, the 'filehandle' (which need not be a real filehandle at
+#pod all) and the current chunk of data.
+#pod
+#pod =back
+#pod
+#pod =cut
 
 sub _stream_to_print {
   my $fh = shift;
@@ -146,6 +225,14 @@ sub body {
   };
 }
 
+#pod =head1 CREDITS
+#pod
+#pod Ricardo SIGNES wrote Email::Simple.
+#pod
+#pod Numerous improvement, especially streamability the handling of pipes, were made
+#pod by Hans Dieter Pearcey.
+#pod
+#pod =cut
 
 1;
 
@@ -153,13 +240,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Simple::FromHandle - an Email::Simple but from a handle
 
 =head1 VERSION
 
-version 0.054
+version 0.055
 
 =head1 SYNOPSIS
 
@@ -180,6 +269,16 @@ of an email.  It will keep a reference to the filehandle and read from it when
 it needs to access the body.  It does not load the entire body into memory and
 keep it there.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 In addition to the standard L<Email::Simple> interface, the following methods
@@ -246,7 +345,23 @@ by Hans Dieter Pearcey.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Hans Dieter Pearcey Ricardo Signes
+
+=over 4
+
+=item *
+
+Hans Dieter Pearcey <hdp@cpan.org>
+
+=item *
+
+Ricardo Signes <rjbs@semiotic.systems>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
